import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.88a9f19a.js";import{B as y}from"./BaseLayout.3e9b7375.js";import{d as p,D as m,K as b,$ as u,aZ as v,a_ as g,o as _,X as h,a as r,Y as s,ed as w,eq as S,W as k,c as L,w as n,b as i,u as $}from"./vue-router.85c27f05.js";import{u as x}from"./editor.533bcc85.js";import{b as B}from"./index.ed82b5e0.js";import"./Logo.c8f3b91c.js";import"./workspaceStore.dbfbf104.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";import"./asyncComputed.cef7b9d8.js";import"./index.b424c289.js";import"./Avatar.77fe15dd.js";import"./index.b39fb56f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2f969694-a6cd-400f-8156-e70b39532a60",e._sentryDebugIdIdentifier="sentry-dbid-2f969694-a6cd-400f-8156-e70b39532a60")}catch{}})();const I=p({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(o)}}});const D={class:"v-spinner"};function P(e,o,a,d,c,l){return v((_(),h("div",D,[r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u(I,[["render",P],["__scopeId","data-v-06538001"]]),R={class:"content"},j=p({__name:"ProjectLogin",setup(e){const o=w(),a=S(),d=x();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function l(){const t=o.query["api-key"];if(typeof t=="string")return t}return k(async()=>{const t=l();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"workspace"})}),(t,z)=>(_(),L(y,null,{navbar:n(()=>[i($(B),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[r("div",R,[i(K)])]),_:1}))}});const Z=u(j,[["__scopeId","data-v-944edebb"]]);export{Z as default};
//# sourceMappingURL=ProjectLogin.dada9811.js.map
