[data-v-47a27891]:root{--abstra-main-color-dark: #343b46}.linter-btn.info[data-v-47a27891]{color:#44a5ff;border-color:#44a5ff}.linter-btn.info[data-v-47a27891]:hover,.linter-btn.info[data-v-47a27891]:active{color:#44a5ff;border-color:#44a5ff;background-color:#e6f4ff}.linter-btn.warning[data-v-47a27891]{color:#ffc400;border-color:#ffc400}.linter-btn.warning[data-v-47a27891]:hover,.linter-btn.warning[data-v-47a27891]:active{color:#ffc400;border-color:#ffc400;background-color:#fffbe6}.linter-btn.error[data-v-47a27891]{color:#ff4f3e;border-color:#ff4f3e}.linter-btn.error[data-v-47a27891]:hover,.linter-btn.error[data-v-47a27891]:active{color:#ff4f3e;border-color:#ff4f3e;background-color:#d3524914}[data-v-a2fa9262]:root{--main-font-family: DM Sans, sans-serif}[data-v-a2fa9262]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-a2fa9262]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-a2fa9262]{background-color:#fff;padding:10px}.deploy-state-message[data-v-a2fa9262]{margin-bottom:8px}.action-buttons[data-v-a2fa9262]{justify-content:flex-end}.deploy-button[data-v-a2fa9262]{display:flex;gap:8px}[data-v-b4cc0fe7]:root{--main-font-family: DM Sans, sans-serif}[data-v-b4cc0fe7]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-b4cc0fe7]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-b4cc0fe7]{background-color:#fff;padding:10px}
