import{d as n,X as d,a as s,Z as a,ea as r,o as l,$ as _}from"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ddf05a43-445c-4f59-92d1-4fe7d0995693",e._sentryDebugIdIdentifier="sentry-dbid-ddf05a43-445c-4f59-92d1-4fe7d0995693")}catch{}})();const f={class:"content-layout"},c=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(l(),d("div",f,[s("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[a(t.$slots,"default",{},void 0,!0)],2)]))}});const i=_(c,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.b8103ab5.js.map
