import"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="d6b9435d-ad8f-4a30-b115-9b57312bf58c",e._sentryDebugIdIdentifier="sentry-dbid-d6b9435d-ad8f-4a30-b115-9b57312bf58c")}catch{}})();const c=e=>{try{return new URL(e),!0}catch{return!1}},b=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([s,a])=>{t.searchParams.delete(s),n.set(s,a)}),`${t.origin}${t.pathname}?${n.toString()}`};export{c as i,b as m};
//# sourceMappingURL=url.2f0a55dd.js.map
