import{_}from"./Login.vue_vue_type_script_setup_true_lang.3b405518.js";import{b as f,u as m}from"./workspaceStore.dbfbf104.js";import{d as l,eq as b,ed as y,X as g,b as w,u as i,o as k,$ as h}from"./vue-router.85c27f05.js";import"./Logo.c8f3b91c.js";import"./CircularLoading.cd545ab6.js";import"./string.76b61cc9.js";import"./index.66331862.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8e8659b2-c86f-4121-9aa1-cc576bfc0f16",e._sentryDebugIdIdentifier="sentry-dbid-8e8659b2-c86f-4121-9aa1-cc576bfc0f16")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=b(),r=y(),p=f(),n=m(),d=async()=>{await p.signUp();const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>{var a,c,u;return k(),g("div",v,[w(_,{"logo-url":(c=(a=i(n).state.workspace)==null?void 0:a.logoUrl)!=null?c:void 0,"brand-name":(u=i(n).state.workspace)==null?void 0:u.brandName,onDone:d},null,8,["logo-url","brand-name"])])}}});const R=h(I,[["__scopeId","data-v-907be835"]]);export{R as default};
//# sourceMappingURL=Login.6432944b.js.map
