import{k as n,T as a,m as r,P as o,C as c,M as d,s as p,n as s,p as m,q as u,t as f,v as g}from"./vue-router.85c27f05.js";import{s as b,c as y,a as i}from"./workspaceStore.dbfbf104.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.a93af74b.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";import"./PlayerConfigProvider.f3ecfff9.js";import"./index.98f5b9bc.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="27c6e6dc-ca31-4e69-8621-d69cb020db2c",t._sentryDebugIdIdentifier="sentry-dbid-27c6e6dc-ca31-4e69-8621-d69cb020db2c")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=y(),e=n({render:()=>m(l)});a.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",c),e.component("Markdown",d),e.component("Message",p),s(e,u),s(e,f),s(e,g)})();
//# sourceMappingURL=player.628f99e3.js.map
