import{eN as n,eO as t}from"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="f59e8f0c-4409-4077-9f1c-4e44f6863985",e._sentryDebugIdIdentifier="sentry-dbid-f59e8f0c-4409-4077-9f1c-4e44f6863985")}catch{}})();function s(e,f){return n(1,arguments),t(e,Date.now(),f)}export{s as f};
//# sourceMappingURL=index.c978f122.js.map
