import{d as r,o,c as d,w as a,b as f,Z as u,u as s,dd as i,ez as l,eC as c,bP as p}from"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="13543e4f-4af7-4417-9f5d-6e9a34368999",e._sentryDebugIdIdentifier="sentry-dbid-13543e4f-4af7-4417-9f5d-6e9a34368999")}catch{}})();const y=r({__name:"AbstraButton",setup(e){return(t,n)=>(o(),d(s(p),l(c(t.$attrs)),{default:a(()=>[f(s(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[u(t.$slots,"default")]),_:3})]),_:3},16))}});export{y as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.7c99a794.js.map
