import"./App.vue_vue_type_style_index_0_lang.a93af74b.js";import{_ as c}from"./App.vue_vue_type_style_index_0_lang.a93af74b.js";import"./workspaceStore.dbfbf104.js";import"./vue-router.85c27f05.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";import"./PlayerConfigProvider.f3ecfff9.js";import"./index.98f5b9bc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="61e16c74-a08c-4564-9e21-eb3f32eb2778",e._sentryDebugIdIdentifier="sentry-dbid-61e16c74-a08c-4564-9e21-eb3f32eb2778")}catch{}})();export{c as default};
//# sourceMappingURL=App.3cbfd89a.js.map
