import{P as m}from"./PlayerNavbar.8fc282b5.js";import{u as f,i as b}from"./workspaceStore.dbfbf104.js";import{d as g,eq as h,ed as i,e as y,f as v,r as k,X as w,u as n,c as L,R as I,a as N,b as C,o as c,$ as R}from"./vue-router.85c27f05.js";import"./metadata.a1d107ae.js";import"./PhBug.vue.cdc6f325.js";import"./PhCheckCircle.vue.d825c360.js";import"./PhKanban.vue.5d3ea6f3.js";import"./PhWebhooksLogo.vue.21427dd7.js";import"./LoadingOutlined.381381bd.js";import"./PhSignOut.vue.6074ad11.js";import"./index.b424c289.js";import"./Avatar.77fe15dd.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="878bbc42-8d14-4189-9956-1b85abb07fb5",t._sentryDebugIdIdentifier="sentry-dbid-878bbc42-8d14-4189-9956-1b85abb07fb5")}catch{}})();const V={class:"main-container"},x={class:"content"},B=g({__name:"Main",setup(t){const e=h(),o=f(),u=i().path,a=y(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=v(()=>!!i().meta.hideLogin);return b(()=>e.push({name:"playerLogin"})),(r,s)=>{const _=k("RouterView");return c(),w("div",V,[n(o).state.workspace?(c(),L(m,{key:0,"current-path":n(u),"hide-login":l.value,"runner-data":n(o).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p},null,8,["current-path","hide-login","runner-data","loading"])):I("",!0),N("section",x,[C(_)])])}}});const H=R(B,[["__scopeId","data-v-f6aef10c"]]);export{H as default};
//# sourceMappingURL=Main.041289cc.js.map
