import{E as y}from"./api.fff15498.js";import{C as w}from"./ContentLayout.b8103ab5.js";import{d as c,L as g,N as b,e as _,c as a,w as d,o as i,b as n,u as o,R as s}from"./vue-router.85c27f05.js";import{K as v,_ as K,W as R,E,a as T}from"./WorkflowView.3eee3ec1.js";import{A as p,T as V}from"./TabPane.576c0d24.js";import"./fetch.474b3c95.js";import"./metadata.a1d107ae.js";import"./PhBug.vue.cdc6f325.js";import"./PhCheckCircle.vue.d825c360.js";import"./PhKanban.vue.5d3ea6f3.js";import"./PhWebhooksLogo.vue.21427dd7.js";import"./polling.9542ae42.js";import"./asyncComputed.cef7b9d8.js";import"./PhQuestion.vue.bcfe90a6.js";import"./ant-design.83748870.js";import"./index.b39fb56f.js";import"./index.c978f122.js";import"./index.eea6e376.js";import"./CollapsePanel.d053599a.js";import"./index.15bd2207.js";import"./index.a7aab5b2.js";import"./Badge.6a9a7808.js";import"./PhArrowCounterClockwise.vue.ee1b0bc1.js";import"./Workflow.eb876838.js";import"./validations.f08f0622.js";import"./string.76b61cc9.js";import"./uuid.23c0712d.js";import"./index.98f5b9bc.js";import"./workspaces.0cf2a9a0.js";import"./workspaceStore.dbfbf104.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";import"./record.b6b15302.js";import"./index.275dcf16.js";import"./PhArrowDown.vue.a3df8116.js";import"./Card.f2bc8e5f.js";import"./LoadingOutlined.381381bd.js";import"./DeleteOutlined.b6524930.js";import"./PhDownloadSimple.vue.3605c6dc.js";import"./utils.6ad8b875.js";import"./LoadingContainer.6b16356d.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="d9c6e925-1576-495a-a142-5ec960328dbd",r._sentryDebugIdIdentifier="sentry-dbid-d9c6e925-1576-495a-a142-5ec960328dbd")}catch{}})();const yo=c({__name:"WorkflowThreads",setup(r){const t=new E,m=new T,u=new g(b.array(b.string()),"kanban-selected-stages"),f=new y,e=_("kanban");return(W,l)=>(i(),a(w,{"full-width":""},{default:d(()=>[n(o(V),{activeKey:e.value,"onUpdate:activeKey":l[0]||(l[0]=k=>e.value=k)},{default:d(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),e.value==="kanban"?(i(),a(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(u),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),e.value==="table"?(i(),a(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),e.value==="workflow"?(i(),a(R,{key:2,"kanban-repository":o(t),"workflow-api":o(f)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{yo as default};
//# sourceMappingURL=WorkflowThreads.c7e4d646.js.map
