import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.88a9f19a.js";import{d as v,ed as A,eq as x,f as w,X as I,b as c,w as a,u as e,c as f,R as p,o as i,aF as s,ec as l,d9 as C,d5 as m,bP as N,a as B,d6 as D,eW as o,$ as T}from"./vue-router.85c27f05.js";import{u as E}from"./workspaceStore.dbfbf104.js";import{C as V}from"./Card.f2bc8e5f.js";import"./Logo.c8f3b91c.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";import"./TabPane.576c0d24.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new H().stack;d&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[d]="8f39ebf0-a1f8-417e-ba8f-780901706503",r._sentryDebugIdIdentifier="sentry-dbid-8f39ebf0-a1f8-417e-ba8f-780901706503")}catch{}})();const R={class:"inner-content"},S={class:"card-content"},$=v({__name:"Error",setup(r){const d=A(),g=x(),u=E(),b=w(()=>{var t,_,y;return(y=(t=u.state.workspace)==null?void 0:t.name)!=null?y:(_=u.state.workspace)==null?void 0:_.brandName}),n=w(()=>{const{status:t}=d.params;switch(t){case"404":return{status:t,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:t,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),h=()=>{g.push({name:"playerHome"})};return(t,_)=>(i(),I("div",R,[c(e(C),null,{default:a(()=>[s(l(n.value.title),1)]),_:1}),c(e(m),{class:"message"},{default:a(()=>[s(l(n.value.message),1)]),_:1}),n.value.action?(i(),f(e(N),{key:0,type:"link",onClick:h},{default:a(()=>[s(l(n.value.action),1)]),_:1})):p("",!0),n.value.showAd?(i(),f(e(V),{key:1,bordered:!1,class:"card"},{default:a(()=>[B("div",S,[c(k,{style:{"margin-bottom":"10px"}}),c(e(m),null,{default:a(()=>[s("This page is part of "+l(b.value?`the ${b.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(u).state.workspace?(i(),f(e(m),{key:0},{default:a(()=>[s("Automate your own processes by getting started "),c(e(D),{href:"https://abstra.io"},{default:a(()=>[s("here")]),_:1}),s(".")]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}});const H=T($,[["__scopeId","data-v-f16a0b67"]]);export{H as default};
//# sourceMappingURL=Error.fcad8cc2.js.map
