import{d as i,c as p,w as n,o as m,b as a,u as t}from"./vue-router.85c27f05.js";import"./editor.533bcc85.js";import{W as d}from"./workspaces.0cf2a9a0.js";import{C as s}from"./ContentLayout.b8103ab5.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.18923626.js";import"./workspaceStore.dbfbf104.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";import"./asyncComputed.cef7b9d8.js";import"./record.b6b15302.js";import"./gateway.aa5a907a.js";import"./popupNotifcation.db970277.js";import"./fetch.474b3c95.js";import"./SaveButton.098ea3be.js";import"./UnsavedChangesHandler.1e13e45a.js";import"./ExclamationCircleOutlined.589179c8.js";import"./CrudView.dfc4572e.js";import"./router.6a11826f.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.2ed94dec.js";import"./BookOutlined.3c422224.js";import"./PhDotsThreeVertical.vue.ceb80819.js";import"./Badge.6a9a7808.js";import"./index.b39fb56f.js";import"./polling.9542ae42.js";import"./PhPencil.vue.e4db48af.js";import"./index.66331862.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="c28c636f-c503-47ad-add7-31952dfb6153",o._sentryDebugIdIdentifier="sentry-dbid-c28c636f-c503-47ad-add7-31952dfb6153")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(m(),p(s,null,{default:n(()=>[a(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(d)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.3b4430ab.js.map
