.outline-button[data-v-2d3b9e41]{cursor:pointer;display:flex;justify-content:center;align-items:center;padding:4px 8px;gap:8px;border-radius:4px;border:1px solid #d14056;font-weight:500;font-size:12px;color:#d14056;flex-shrink:0;box-shadow:1px 1px 3px #0000000f;background-color:transparent;box-sizing:border-box;height:26px}.outline-button .icon[data-v-2d3b9e41]{height:16px;width:16px}.outline-button .icon[data-v-2d3b9e41] path{fill:#d14056}.outline-button[data-v-2d3b9e41]:hover{background:#f9fafb}.outline-button[data-v-2d3b9e41]:active{background:#f9fafb;box-shadow:inset 1px 1px 2px #0000001a;border-color:transparent}.outline-button.disabled[data-v-2d3b9e41]{cursor:unset;background:#f3f4f6;border:1px solid #bdc3cc;color:#bdc3cc}.outline-button.disabled[data-v-2d3b9e41]:hover,.outline-button.disabled[data-v-2d3b9e41]:active{background:#f3f4f6;box-shadow:none}.outline-button.disabled .icon[data-v-2d3b9e41] path{fill:#bdc3cc}[data-v-39354e61]:root{--main-font-family: DM Sans, sans-serif}[data-v-39354e61]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-39354e61]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-39354e61]{background-color:#fff;padding:10px}.form-auto-fill-btn[data-v-39354e61]{background-color:#fff!important}[data-v-6fcb158a]:root{--main-font-family: DM Sans, sans-serif}[data-v-6fcb158a]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-6fcb158a]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-6fcb158a]{background-color:#fff;padding:10px}header[data-v-6fcb158a]{display:flex;width:100%;box-sizing:border-box;color:var(--font-color, #000)}.span-error[data-v-6fcb158a]{color:red}.disabled[data-v-6fcb158a]{filter:blur(8px);pointer-events:none;background-color:#e8e8e8}.unsaved-changes[data-v-6fcb158a]{position:absolute;z-index:1}.center[data-v-6fcb158a]{width:100%;height:100%;display:flex;position:relative;flex-direction:column;align-items:center;justify-content:center}.widget[data-v-6fcb158a]{position:relative}.widget .hint[data-v-6fcb158a]{position:relative;top:0;right:0}.buttons[data-v-6fcb158a]{display:flex;flex-direction:row;gap:1rem;justify-content:flex-end;align-items:center;width:100%;flex-wrap:wrap}.buttons .disabled[data-v-6fcb158a]{opacity:.5;cursor:not-allowed}.loading-wrapper[data-v-6fcb158a]{display:flex;flex-grow:1;justify-content:center;align-items:center;height:100%;width:100%}.auto-fill-btn[data-v-6fcb158a]{position:absolute;bottom:20px;left:20px}
