import{cI as n}from"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="db100cea-37c4-4adb-83a6-46e4e532af2b",e._sentryDebugIdIdentifier="sentry-dbid-db100cea-37c4-4adb-83a6-46e4e532af2b")}catch{}})();const t=(e,r,d)=>{n.error({message:e,description:r,onClick:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.db970277.js.map
