import{b as o,eh as u,el as a}from"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4c4d44ef-58b2-448c-a378-0d180206ccb6",e._sentryDebugIdIdentifier="sentry-dbid-4c4d44ef-58b2-448c-a378-0d180206ccb6")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(l){return Object.getOwnPropertyDescriptor(r,l).enumerable}))),n.forEach(function(l){d(e,l,r[l])})}return e}function d(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var c=function(t,r){var n=i({},t,r.attrs);return o(u,i({},n,{icon:a}),null)};c.displayName="CloseCircleOutlined";c.inheritAttrs=!1;const s=c;export{s as C};
//# sourceMappingURL=CloseCircleOutlined.b938039d.js.map
