import{d as i,ek as l,f as d,X as t,R as r,ec as _,o as a,$ as g}from"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="98d27d11-a130-45c2-8973-7154960a68e4",e._sentryDebugIdIdentifier="sentry-dbid-98d27d11-a130-45c2-8973-7154960a68e4")}catch{}})();const p={class:"logo"},u=["src","alt"],m={key:1},f=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const o=e;l(s=>({"4352941e":n.value}));const n=d(()=>o.size==="large"?"80px":"50px"),c=d(()=>`${o.brandName} Logo`);return(s,y)=>(a(),t("div",p,[s.imageUrl?(a(),t("img",{key:0,class:"logo-img",src:s.imageUrl,alt:c.value},null,8,u)):r("",!0),s.hideText?r("",!0):(a(),t("span",m,_(s.brandName),1))]))}});const h=g(f,[["__scopeId","data-v-16688d14"]]);export{h as L};
//# sourceMappingURL=Logo.c8f3b91c.js.map
