import{B as r}from"./BookOutlined.3c422224.js";import{d as c,o as a,c as f,w as o,b as l,u as n,Z as u,X as i,aF as p,aR as b,bP as y}from"./vue-router.85c27f05.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="538657ef-4b40-40e8-a72c-8d89e0d061dd",t._sentryDebugIdIdentifier="sentry-dbid-538657ef-4b40-40e8-a72c-8d89e0d061dd")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,d)=>{var s;return a(),f(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(r))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.2ed94dec.js.map
