import{d,o as t,X as o,b as s,u as r,bx as _,$ as i}from"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="58595aba-32d0-44d9-8b24-54f17fbadedb",e._sentryDebugIdIdentifier="sentry-dbid-58595aba-32d0-44d9-8b24-54f17fbadedb")}catch{}})();const c={class:"centered"},f=d({__name:"LoadingContainer",setup(e){return(n,a)=>(t(),o("div",c,[s(r(_))]))}});const p=i(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.6b16356d.js.map
