import"./vue-router.85c27f05.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="7410abbb-001e-4f89-ae77-8be70dca9298",x._sentryDebugIdIdentifier="sentry-dbid-7410abbb-001e-4f89-ae77-8be70dca9298")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid.23c0712d.js.map
