.twin-container[data-v-5f7e2cd2]{display:flex;align-items:center;gap:20px}.right-arrow[data-v-5f7e2cd2]{width:50px}.using-container[data-v-5f7e2cd2]{display:flex;gap:40px}.fullwidth-input[data-v-5f7e2cd2]{width:100%}.icon[data-v-6ae5cef6]{cursor:pointer;display:flex}:root{--main-font-family: DM Sans, sans-serif}:root{--abstra-main-color-dark: #343b46}.p-dropdown{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel{background-color:#fff;padding:10px}.table-data{padding:30px 0}.table-row{overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.table-row.null{color:#ccc}.table-row.expanded{white-space:normal}.button-container{display:flex;justify-content:center;align-items:center}
