import{b as o,eh as u,eM as c}from"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="47e5725b-5932-4bb2-acdc-6b07dda00105",e._sentryDebugIdIdentifier="sentry-dbid-47e5725b-5932-4bb2-acdc-6b07dda00105")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){f(e,a,n[a])})}return e}function f(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var d=function(t,n){var r=i({},t,n.attrs);return o(u,i({},r,{icon:c}),null)};d.displayName="LoadingOutlined";d.inheritAttrs=!1;const l=d;export{l as L};
//# sourceMappingURL=LoadingOutlined.381381bd.js.map
