import{b as r,u as n}from"./workspaceStore.dbfbf104.js";import{W as c}from"./PlayerConfigProvider.f3ecfff9.js";import{d,g as i,r as f,u as o,c as u,w as p,R as l,o as _,b as m}from"./vue-router.85c27f05.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="401a3bf2-1078-4157-bd61-8dfa907db09e",t._sentryDebugIdIdentifier="sentry-dbid-401a3bf2-1078-4157-bd61-8dfa907db09e")}catch{}})();const h=d({__name:"App",setup(t){const a=r(),e=n();return e.actions.fetch(),i(()=>a.user,e.actions.fetch),(b,w)=>{const s=f("RouterView");return o(e).state.workspace?(_(),u(c,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:p(()=>[m(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):l("",!0)}}});export{h as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.a93af74b.js.map
