import{i as k}from"./metadata.a1d107ae.js";import{W as h}from"./Watermark.0dfb10b7.js";import{F as w}from"./PhArrowSquareOut.vue.ff1add13.js";import{d as v,eq as b,f as x,e as C,u as e,X as m,b as c,w as r,R as D,o as a,c as n,aF as f,d5 as y,aR as I,ee as z,dd as _,ef as F,ec as T,ea as B,$ as H}from"./vue-router.85c27f05.js";import{u as L}from"./workspaceStore.dbfbf104.js";import"./index.4bd4f417.js";import{L as N}from"./LoadingOutlined.381381bd.js";import{C as R}from"./Card.f2bc8e5f.js";import"./PhBug.vue.cdc6f325.js";import"./PhCheckCircle.vue.d825c360.js";import"./PhKanban.vue.5d3ea6f3.js";import"./PhWebhooksLogo.vue.21427dd7.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";import"./TabPane.576c0d24.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="952316d4-0042-4947-aa9d-2046d0bf0708",o._sentryDebugIdIdentifier="sentry-dbid-952316d4-0042-4947-aa9d-2046d0bf0708")}catch{}})();const S={key:0,class:"home-container"},V=v({__name:"Home",setup(o){const i=b(),l=L(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(p=>p.id!=="home"))||[]}),d=C(null),g=async(s,p)=>{d.value=p,await i.push({path:`/${s}`}),d.value=null};return(s,p)=>e(l).state.workspace?(a(),m("div",S,[c(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(a(!0),m(I,{key:1},z(u.value,t=>(a(),n(e(R),{key:t.id,class:B(["form-card",{loading:d.value===t.id}]),"body-style":{cursor:"pointer"},onClick:W=>g(t.path,t.id)},{default:r(()=>[c(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(F(e(k)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),c(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(T(t.name),1)]),_:2},1024),d.value!==t.id?(a(),n(e(w),{key:0,size:"20"})):(a(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),c(h,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):D("",!0)}});const Z=H(V,[["__scopeId","data-v-060376d1"]]);export{Z as default};
//# sourceMappingURL=Home.8d7ec2b2.js.map
