import{O as r}from"./workspaceStore.dbfbf104.js";import{d as i,W as l,X as u,b as a,w as n,u as o,o as c,aF as d,d9 as f,d8 as b}from"./vue-router.85c27f05.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="96ea0970-e0f9-498f-8e93-b5e6545d0d1b",e._sentryDebugIdIdentifier="sentry-dbid-96ea0970-e0f9-498f-8e93-b5e6545d0d1b")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.b7ce2f19.js.map
