import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.18923626.js";import{d as i,ed as s,c as a,u as m,o as c}from"./vue-router.85c27f05.js";import"./gateway.aa5a907a.js";import"./popupNotifcation.db970277.js";import"./fetch.474b3c95.js";import"./record.b6b15302.js";import"./SaveButton.098ea3be.js";import"./UnsavedChangesHandler.1e13e45a.js";import"./ExclamationCircleOutlined.589179c8.js";import"./CrudView.dfc4572e.js";import"./router.6a11826f.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.2ed94dec.js";import"./BookOutlined.3c422224.js";import"./url.2f0a55dd.js";import"./PhDotsThreeVertical.vue.ceb80819.js";import"./Badge.6a9a7808.js";import"./index.b39fb56f.js";import"./asyncComputed.cef7b9d8.js";import"./polling.9542ae42.js";import"./PhPencil.vue.e4db48af.js";import"./index.66331862.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="a43f0b58-dcb2-4729-a932-c353443ce61b",o._sentryDebugIdIdentifier="sentry-dbid-a43f0b58-dcb2-4729-a932-c353443ce61b")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(d,f)=>(c(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.1d35acc3.js.map
