import{O as d}from"./workspaceStore.dbfbf104.js";import{d as l,W as i,X as u,b as t,w as o,u as n,o as c,aF as s,d9 as f,d8 as b}from"./vue-router.85c27f05.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="350ea9a8-aa19-4144-8160-7c759b874a9b",e._sentryDebugIdIdentifier="sentry-dbid-350ea9a8-aa19-4144-8160-7c759b874a9b")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new d().logoutCallback()}),(a,r)=>(c(),u("div",null,[t(n(f),null,{default:o(()=>[s("You're authenticated")]),_:1}),t(n(b),null,{default:o(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.07feea7c.js.map
