.sql-container[data-v-a13d7ced]{padding:12px;background-color:#fff;border-radius:8px;margin-bottom:20px;box-shadow:0 0 10px #0000001a;height:fit-content}.sql-editor[data-v-a13d7ced]{width:100%;height:180px;border-radius:6px}
