import{C as t,E as d,K as i,a as f,M as c,c as l,P as y,R as g,S as u,b,T as k,U as p,e as w,l as D}from"./toggleHighContrast.789c5cde.js";import"./vue-router.85c27f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ffad3300-0675-4581-8537-d3ca3a0383a5",e._sentryDebugIdIdentifier="sentry-dbid-ffad3300-0675-4581-8537-d3ca3a0383a5")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,f as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,g as Range,u as Selection,b as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.141ee28f.js.map
