import{P as k}from"./api.fff15498.js";import{b as _}from"./workspaceStore.dbfbf104.js";import{d as w,L as g,N as d,e as v,X as h,b as r,w as T,u as e,c as p,R as m,o as s,$ as K}from"./vue-router.85c27f05.js";import{K as R,_ as I,W as P,P as S,b as V}from"./WorkflowView.3eee3ec1.js";import{A as l,T as x}from"./TabPane.576c0d24.js";import"./Card.f2bc8e5f.js";import"./fetch.474b3c95.js";import"./metadata.a1d107ae.js";import"./PhBug.vue.cdc6f325.js";import"./PhCheckCircle.vue.d825c360.js";import"./PhKanban.vue.5d3ea6f3.js";import"./PhWebhooksLogo.vue.21427dd7.js";import"./url.2f0a55dd.js";import"./colorHelpers.569fabfb.js";import"./polling.9542ae42.js";import"./asyncComputed.cef7b9d8.js";import"./PhQuestion.vue.bcfe90a6.js";import"./ant-design.83748870.js";import"./index.b39fb56f.js";import"./index.c978f122.js";import"./index.eea6e376.js";import"./CollapsePanel.d053599a.js";import"./index.15bd2207.js";import"./index.a7aab5b2.js";import"./Badge.6a9a7808.js";import"./PhArrowCounterClockwise.vue.ee1b0bc1.js";import"./Workflow.eb876838.js";import"./validations.f08f0622.js";import"./string.76b61cc9.js";import"./uuid.23c0712d.js";import"./index.98f5b9bc.js";import"./workspaces.0cf2a9a0.js";import"./record.b6b15302.js";import"./index.275dcf16.js";import"./PhArrowDown.vue.a3df8116.js";import"./LoadingOutlined.381381bd.js";import"./DeleteOutlined.b6524930.js";import"./PhDownloadSimple.vue.3605c6dc.js";import"./utils.6ad8b875.js";import"./LoadingContainer.6b16356d.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="f47a9592-5e7c-4c6f-9c54-72137d0b4ae3",t._sentryDebugIdIdentifier="sentry-dbid-f47a9592-5e7c-4c6f-9c54-72137d0b4ae3")}catch{}})();const W={class:"threads-view"},A=w({__name:"Threads",setup(t){const a=_().authHeaders,b=new k(a),i=new S(a),u=new V(a),y=new g(d.array(d.string()),"kanban-selected-stages"),o=v("kanban");return(B,c)=>(s(),h("div",W,[r(e(x),{activeKey:o.value,"onUpdate:activeKey":c[0]||(c[0]=f=>o.value=f)},{default:T(()=>[r(e(l),{key:"kanban",tab:"Kanban View"}),r(e(l),{key:"table",tab:"Table View"}),r(e(l),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(s(),p(R,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(u)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(s(),p(I,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(s(),p(P,{key:2,"kanban-repository":e(i),"workflow-api":e(b)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=K(A,[["__scopeId","data-v-d2894db4"]]);export{ge as default};
//# sourceMappingURL=Threads.24257fb7.js.map
